%   SHUTDOWNRCX.M  -    saves the state of the given RCX to file, including
%                       its calibration parameters and current position.
%                       and then shuts down the RCX, and frees up the
%                       resources used by the PCAngleLayer object.
%
%   usage:  shutdownrcx(rcx)
%
%   where:  rcx     is an instance of the PCAngleLayer class
%
%   UWA PC307 Group M
%   By Philip Hagen
%   hagenp01@tartarus.uwa.edu.au
%   10 October 2003

function shutdownrcx(rcx)

    if (~is(rcx, 'PCAngleLayer'))
        error('shutdownrcx.m: expected 1 parameter that is an instance of Java class PCAngleLayer.');
    end

    calibdata = rcx.getCalibrationData;
    pos = rcx.getPosition;

    yawratio = calibdata.getYawRatio;
    pitchratio = calibdata.getPitchRatio;

    yaw = pos.getYaw;
    pitch = pos.getPitch;
    
    save 'rcxstate.mat' yaw pitch yawratio pitchratio;

    rcx.shutdown;
    clear rcx;
    
