//  CalibrationData.java

/**
 *  This class represents calibration data to allow the RCX
 *  to work in terms of angles in degrees, rather than sensor
 *  values.
 *
 *  @author Philip Hagen
 *  @version %I%, %G%
 */

public class CalibrationData
{

    private double yawratio;
    private double pitchratio;

    /**
    * Constructor which sets the yaw and pitch ratio.
    *
    * @param    yr  the double value for the yaw ratio
    * @param    pr  the double value for the pitch ratio
    */
    public CalibrationData(double yr, double pr)
    {
        yawratio = yr;
        pitchratio = pr;
    }

    /**
    * Constructor which clones the calibration data.
    *
    * @param    cd  the calibration data object to be cloned
    */
    public CalibrationData(CalibrationData cd)
    {
        cloneData(cd);
    }

    /**
     * Clones the calibration data.
     *
     * @param   cd  the calibration data.
     */
    public void cloneData(CalibrationData cd)
    {
        this.yawratio = cd.yawratio;
        this.pitchratio = cd.pitchratio;
    }

    /**
     * Returns the value of the yaw ratio.
     *
     * @return  the yaw ratio
     */
    public double getYawRatio()
    {
        return yawratio;
    }

    /**
     * Returns the value of the pitch ratio.
     *
     * @return  the pitch ratio
     */
    public double getPitchRatio()
    {
        return pitchratio;
    }

    /**
     * Sets the value of the pitch ratio.
     *
     * @param   pr  the pitch ratio to be set
     */
    public void setPitchRatio(double pr)
    {
        pitchratio = pr;
    }

    /**
     * Sets the value of the yaw ratio.
     *
     * @param   yr  the yaw ratio to be set
     */
    public void setYawRatio(double yr)
    {
        yawratio = yr;
    }


}

