//  CamPosition.java

/**
 *  This class represents a camera position, which consists
 *  of a yaw angle and a pitch angle.
 *
 *  Yaw is the angle along the horizontal plane (ie. left/right),
 *  and pitch is the angle along the vertical plane (ie. up/down).
 *
 *  @author Philip Hagen
 *  @version %I%, %G%
 */


public class CamPosition
{

    private int yaw;
    private int pitch;

    /**
     * Constructor which sets the current yaw and pitch values for this camera position.
     *
     * @param   yaw      the yaw value of the current position
     * @param   pitch     the pitch value of the current position
     */
    public CamPosition(int yaw, int pitch)
    {
        this.yaw = yaw;
        this.pitch = pitch;
    }

    /**
     * Constructor which clones the current camera position object.
     *
     * @param   cp      the camera position data object to be cloned
     */
    public CamPosition(CamPosition cp)
    {
        cloneData(cp);
    }

    /**
     * Constructor which calculates the camera position from given sensor values
     * and calibration data.
     *
     * @param sensorvals    the current camera sensor values
     * @param calibdata        the calibration data
     */
    public CamPosition(SensorValues sensorvals, CalibrationData calibdata)
    {
        // work out the camera position, given sensor values and                                                                                ?????????
        // calibration data.
    }

    /**
    * Clones the camera position data.
    *
    * @param    cp  the camera position data object to be cloned
    */
    public void cloneData(CamPosition cp)
    {
        this.yaw = cp.yaw;
        this.pitch = cp.pitch;
    }

    /**
     * Returns the current camera yaw value.
     *
     * @return  the yaw value
     */
    public int getYaw()
    {
        return yaw;
    }

    /**
     * Returns the current camera pitch value.
     *
     * @return  the pitch value
     */
    public int getPitch()
    {
        return pitch;
    }

    /**
     * Sets the current camera position with current yaw and pitch values.
     *
     * @param   yaw     the yaw value to be set
     * @param   pitch   the pitch value to be set
     */
    public void setPosition(int yaw, int pitch)
    {
        this.yaw = yaw;
        this.pitch = pitch;
    }

    /**
     * Sets the current camera position yaw value.
     *
     * @param   yaw     the yaw value to be set
     */
    public void setYaw(int yaw)
    {
        this.yaw = yaw;
    }

    /**
     * Sets the current camera position pitch value.
     *
     * @param   pitch   the pitch value to be set
     */
    public void setPitch(int pitch)
    {
        this.pitch = pitch;
    }

    /**
     * Calculates and returns the distance from the current position to the target position.
     *
     * @param   newpos  the target position as a camera position object
     * @return  the camera position object of the distance from the current position to the target position
     */
    public CamPosition getVectorTo(CamPosition newpos)
    {
        return new CamPosition(newpos.yaw - this.yaw, newpos.pitch - this.pitch);
    }

    /*
    public double getMagnitude()
    {
        // note sure if we can use the square-root function on the RCX
        return Math.sqrt( yaw*yaw + pitch*pitch );
    }*/

}
