// IRMessage.java

/**
 *  This class represents an IR message recieved from the PC.
 *
 *  @author Philip Hagen    hagenp01@tartarus.uwa.edu.au
 *  @version %I%, %G%
 *
 */


public class IRMessage
{

    int code;
    int[] params;
    int n;

    /**
    * Default constructor.
    */
    public IRMessage()
    {
        this.code = 0;
        this.params = new int[4];
        this.n = 0;
    }

    /**
    * Gets the meesage code.
    *
    *   @return     a predefined communications message code
    */
    public int getCode()
    {
        return code;
    }

    /**
    * Gets the number of parameters expected by a particular RCX function.
    *
    *   @return the number of parameters
    */
    public int getParamCount()
    {
        return n;
    }
    /**
    * Gets the actual parameter value
    *
    *   @return  the parameter value
    */
    public int getParam(int i)
    {
        if ((i >= 0) && (i < n))
        {
            return params[i];
        }
        return -1;
    }

    /**
    * Sets the communications code value, for a function with no arguments.
    *
    * @param    c   the code value
    */
    public void set(int c)
    {
        this.code = c;
        this.n = 0;
    }

    /**
    * Sets the communications code value, for a function with 1 argument.
    *
    * @param    c   the code value
    * @param    p1  the value of the argument
    */
    public void set(int c, int p1)
    {
        this.code = c;
        this.params[0] = p1;
        this.n = 1;
    }
           
    /**
    * Sets the communications code value, for a function with 2 arguments.
    *
    * @param    c   the code value
    * @param    p1  the value of the first argument
    *  @param    p2  the value of the second argument
    */
    public void set(int c, int p1, int p2)
    {
        this.code = c;
        this.params[0] = p1;
        this.params[1] = p2;
        this.n = 2;
    }

    /**
    * Sets the communications code value, for a function with 3 arguments.
    *
    * @param    c   the code value
    * @param    p1  the value of the first argument
    *  @param    p2  the value of the second argument
    *  @param    p3  the value of the third argument
    */
    public void set(int c, int p1, int p2, int p3)
    {
        this.code = c;
        this.params[0] = p1;
        this.params[1] = p2;
        this.params[2] = p3;
        this.n = 3;
    }

    /**
    * Sets the communications code value, for a function with 4 arguments.
    *
    * @param    c   the code value
    * @param    p1  the value of the first argument
    *  @param    p2  the value of the second argument
    *  @param    p3  the value of the third argument
    *  @param    p4  the value of the forth argument
    */
    public void set(int c, int p1, int p2, int p3, int p4)
    {
        this.code = c;
        this.params[0] = p1;
        this.params[1] = p2;
        this.params[2] = p3;
        this.params[3] = p4;
        this.n = 4;
    }
    
    
    /*
    public IRMessage(int c)
    {
        this.code = c;
        this.params = new int[0];
    }

    public IRMessage(int c, int p1)
    {
        this.code = c;
        this.params = new int[1];
        this.params[0] = p1;
    }

    public IRMessage(int c, int p1, int p2)
    {
        this.code = c;
        this.params = new int[2];
        this.params[0] = p1;
        this.params[1] = p2;
    }

    public IRMessage(int c, int p1, int p2, int p3)
    {
        this.code = c;
        this.params = new int[3];
        this.params[0] = p1;
        this.params[1] = p2;
        this.params[2] = p3;
    }

    public IRMessage(int c, int p1, int p2, int p3, int p4)
    {
        this.code = c;
        this.params = new int[4];
        this.params[0] = p1;
        this.params[1] = p2;
        this.params[2] = p3;
        this.params[3] = p4;
    }

    public IRMessage(IRMessage msg)
    {
        code = msg.code;
        for (int i=0; i<msg.params.length; i++)
            params[i] = msg.params[i];
    }

    public int getParamCount()
    {
        return params.length;
    }

    public int getCode()
    {
        return code;
    }

    public int getParam(int i)
    {
        if ((i >= 0) && (i < params.length))
        {
            return params[i];
        }
        return -1;
    }
    */

}
