// ImagePanel.java
/**
 *  Part of PC307 Group M Project: Lego RCX WebCam Mount
 *  Category: PC Imaging
 *
 *  This class is basically a JPanel, that can be placed on a form,
 *  that displays a live feed from a webcam.
 *  It uses a WebCamCapture object to get the data from the webcam.
 *
 *  @author Nevin Doss
 *
 *  Last updated: 10 October 2003
 */

import java.awt.GridLayout;
import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;

public class ImagePanel extends JPanel {

    // the WebCamCapture object used to grab data from the webcam
    private WebCamCapture wcc = new WebCamCapture();

    // flag that determines whether crosshair is drawn or not
    private boolean crossHair = false;


    /** Turns the crosshair on or off.  The crosshair is drawn over
     *  the center of the image, and is used for calibration.
     *
     *  @params   crossHair   true to enable the crosshair, or false
     *                        to disable the crosshair.
     */
    public void setCrossHair(boolean crossHair){
        this.crossHair = crossHair;
    }

    /** Constructor to create an ImagePanel.  Sets up a stream
     *  from the camera.
     */
    public ImagePanel() {
        super();
        JLabel label1;
        try {
        wcc.setup(wcc.getCameraName());
        wcc.start();
        } catch (Exception e){
        e.printStackTrace();
            }

        ImageIcon icon = new ImageIcon((Image)wcc.getBufferedImage());
        //Create the label.
        label1 = new JLabel(icon);

        // add the label
        add(label1);
        this.show();

        Timer timer = new Timer(10, repaintaction);
        timer.start();
    }

    private Action repaintaction = new AbstractAction()
    {
        public void actionPerformed(ActionEvent e)
        {
            repaint();
        }
    };

    /**
     * Paint the current frame
     */
    public void paint(Graphics g) {
        g.drawImage((Image)wcc.getBufferedImage(), super.getX(), super.getY(), this);

        if(crossHair){
        Graphics2D g2 = (Graphics2D)g;
        int w = getSize().width;
        int h = getSize().height;
        int bw = wcc.getBufferedImage().getWidth(this);
        int bh = wcc.getBufferedImage().getHeight(this);

        g2.setColor(Color.black);
        g2.setStroke(new BasicStroke(2.0f));
        g2.drawLine((bw/2)-5, (bh/2), (bw/2)+5, (bh/2));
        g2.drawLine((bw/2), (bh/2)-5, (bw/2), (bh/2)+5);
        }
    }

    /**
     *  Causes the image capture to stop.  Should be called before destroying the
     *  object to ensure that resources are freed properly.
     */
    public void quit()
    {
        wcc.quit();
    }

    protected void finalize()
    {
        quit();
    }

}
