//  SensorValues.java

/**
 *  This class represents the sensor values from the yaw & pitch
 *  rotation sensors on the RCX.
 *
 *  @author Philip Hagen
 *  @version %I%, %G%
 */

public class SensorValues
{

    private int yawval;
    private int pitchval;

    /**
     * Constructor for current yaw and pitch sensor values.
     *
     * @param   yr  the yaw value of the sensor
     * @param   pr  the pitch value of the sensor
     */
    public SensorValues(int yr, int pr)
    {
        yawval = yr;
        pitchval = pr;
    }

    /**
     * Constructor which clones the current sensor values object.
     *
     * @param   sv      the sensor values data object to be cloned
     */
    public SensorValues(SensorValues sv)
    {
        cloneData(sv);
    }

    /**
     * Returns the current yaw sensor value.
     *
     * @return  the yaw sensor value
     */
    public int getYawValue()
    {
        return yawval;
    }

    /**
     * Sets the current yaw sensor value.
     *
     * @param   yaw     the yaw sensor value to be set
     */
    public void setYawValue(int yaw)
    {
        yawval = yaw;
    }

    /**
     * Returns the current  pitch sensor value.
     *
     * @return  the pitch sensor value
     */
    public int getPitchValue()
    {
        return pitchval;
    }

    /**
     * Sets the current pitch sensor value.
     *
     * @param   pitch   the pitch sensor value to be set
     */
    public void setPitchValue(int pitch)
    {
        pitchval = pitch;
    }

    /**
    * Clones the sensor values data.
    *
    * @param    sv  the sensor values data object to be cloned
    */
    public void cloneData(SensorValues sv)
    {
        yawval = sv.yawval;
        pitchval = sv.pitchval;
    }

}
